==> webkitgtk-2.10.2.tar.xz: webkitgtk-2.10.2/Source/JavaScriptCore/profiler/ProfilerJettisonReason.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef ProfilerJettisonReason_h
#define ProfilerJettisonReason_h

namespace JSC { namespace Profiler {

enum JettisonReason {
    NotJettisoned,
    JettisonDueToWeakReference,
    JettisonDueToDebuggerBreakpoint,
    JettisonDueToDebuggerStepping,
    JettisonDueToLegacyProfiler,
    JettisonDueToBaselineLoopReoptimizationTrigger,
    JettisonDueToBaselineLoopReoptimizationTriggerOnOSREntryFail,
    JettisonDueToOSRExit,
    JettisonDueToProfiledWatchpoint,
    JettisonDueToUnprofiledWatchpoint
};

} } // namespace JSC::Profiler

namespace WTF {

class PrintStream;
void printInternal(PrintStream&, JSC::Profiler::JettisonReason);

} // namespace WTF

#endif // ProfilerJettisonReason_h

==> webkitgtk-2.14.0.tar.xz: webkitgtk-2.14.0/Source/JavaScriptCore/profiler/ProfilerJettisonReason.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef ProfilerJettisonReason_h
#define ProfilerJettisonReason_h

namespace JSC { namespace Profiler {

enum JettisonReason {
    NotJettisoned,
    JettisonDueToWeakReference,
    JettisonDueToDebuggerBreakpoint,
    JettisonDueToDebuggerStepping,
    JettisonDueToBaselineLoopReoptimizationTrigger,
    JettisonDueToBaselineLoopReoptimizationTriggerOnOSREntryFail,
    JettisonDueToOSRExit,
    JettisonDueToProfiledWatchpoint,
    JettisonDueToUnprofiledWatchpoint,
    JettisonDueToOldAge
};

} } // namespace JSC::Profiler

namespace WTF {

class PrintStream;
void printInternal(PrintStream&, JSC::Profiler::JettisonReason);

} // namespace WTF

#endif // ProfilerJettisonReason_h
